@@ -79,7 +79,8 @@ class System:
                 onion = fp.read()
         except FileNotFoundError:
             onion = None
-        domains = []
+        with open("domains") as fp:
+            domains = fp.readlines()
         webint_metadata = importlib.metadata.metadata("webint")
         webint_versions = get_versions("webint")
         return app.view.index(
